{% raw %}
{% load mote_tags %}
<div class="article-tag">
  <ul class="article-tag-list">
    <li class="article-tag__item">
      <h4 class="heading heading--small article-tag__item--tags__title">Tags</h4>
    </li>
    <li class="tags-list__item">
      <a href="#">TagNameShort</a>
    </li>
    <li class="tags-list__item">
      <a href="#">TagNamelooong</a>
    </li>
    <li class="tags-list__item">
      <a href="#">ThisIsATagNameThatIsRatherlooong</a>
    </li>
  </ul>
</div>
{% endraw %}
