{% raw %}
{% load mote_tags %}
{% mask element.json.data.Breadcrumb as "breadcrumb" %}
<div class="breadcrumbs">
  <ul class="breadcrumbs-list">
  {% for item in breadcrumb.breadcrumb_links %}
    <li class="breadcrumbs-list__item">
      <a href="{{ item.src }}" class="breadcrumbs-list__anchor is-active">
        {{ item.title }}
      </a>
    </li>
  {% endfor %}
  </ul>
</div>
{% endraw %}
