.call-to-action--profile-icon {
  .call-to-action__item-text--login:after {
    float: right;
    display: block;
    vertical-align: middle;
    @media screen and (min-width: 320px) {
      padding: 5px 15px 0 0;
      content: ">";
    }
    @media screen and (min-width: 490px) {
      content: "❯";
    }
  }
}
