.heading--xx-large {
  @include heading-fontsize-scale($heading-xx-large);
}
.heading--x-large {
  @include heading-fontsize-scale($heading-x-large);
}
.heading--large {
  @include heading-fontsize-scale($heading-large);
}


.heading--small {
  font-size: $font-small;
}
.heading--x-small {
  font-size: $font-x-small;
}
.heading--xx-small {
  font-size: $font-xx-small;
}
