{% include "patterns/basics/languages/language-list-center.html" %}
<div id="header" class="header">
  {% include "patterns/basics/menu/sp_variations/menu-full_with-icons.html" %}
  {% include "patterns/basics/navigations/sp_variations/navigation-category_full.html" %}
</div>
