{% load wagtailcore_tags core_tags i18n %}
{% block tag_menu_homepage %}
<div class="tag-cloud">
  {% load_tags as tags %}
  <div class="tag-cloud__icon"></div>
  <div class="tag-cloud__container">
    <div class="tag-cloud__heading">
      <h4>{% trans "Read stories about"%}</h4>
    </div>
    <ul class="tag-cloud__block">
      {% for tag in tags %}
        {% if tag %}
        <li class="tag-cloud__item">
          <a href="{% url 'tags_list' tag.slug %}" class="tag-cloud__anchor">{{tag.title}}</a>
        </li>
        {% endif %}
      {% endfor %}
    </ul>
  </div>
</div>
{% endblock %}
