{% block navigation %}
  {% load wagtailcore_tags  core_tags i18n %}

  {% block section_menu %}
  <div class="navigation">
    {% load_sections as sections %}
    <h4 class="heading heading--large">
      <a href="/" class="navigation__anchor"> 
        {% trans "Home" %}
      </a>
    </h4>
    <h4 class="heading heading--large">{% trans "Categories" %}</h4>
    <ul class="nav-list">
      {% for section in sections %}
        <li class="nav-list__item">
          <a href="{% pageurl section %}" class="nav-list__anchor">
            {{section.title}}
          </a>
        </li>
      {% endfor %}
    </ul>
  </div>
  {% endblock %}
{% endblock %}
