
.unordered-list {
  padding-right: 10px;
  padding-bottom: 20px;
  .unordered-list__item {
    padding: 5px 0;
  }
}

.ordered-list {
  list-style: decimal;
  padding-bottom: 20px;
  .ordered-list__item {
    padding: 5px 0;
  }
}
