.color-chip {
  display: inline-block;;
  border-top-width: 30px;
  border-top-style: solid;
  border-bottom-width: 0;
  border-bottom-style: solid;
  background-color: #fff;
  font-weight: 700;
  font-size: 15px;
  padding: 16px;
  margin:0 0 35px 5px;
  text-align: center;
  min-width: 100px;
}

.color-chip__name {
  text-transform: capitalize;
}
.color-chip__color {
  font-weight: 400;
}
