# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-14 10:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0037_add_article_body_media_field'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='global_ga_tag_manager',
            field=models.CharField(blank=True, help_text='Global GA Tag Manager tracking code (e.g GTM-XXX)', max_length=255, null=True, verbose_name='Global GA Tag Manager'),
        ),
    ]
