{% load wagtailcore_tags wagtailimages_tags static core_tags %}
{% if articles %}
  <div class="pagination">
    {% if articles_paginated.has_previous %}
      <a href="?p={{ articles_paginated.previous_page_number }}" class="pagination__nav-anchor-previous"></a>
    {% endif %}
    <span class="pagination__current-page">
      Page {{ articles_paginated.number }} of {{ articles_paginated.paginator.num_pages }}
    </span>
    {% if articles_paginated.has_next %}
      <a href="?p={{ articles_paginated.next_page_number }}" class="pagination__nav-anchor-next"></a>
    {% endif %}
  </div>
{% endif %}
