.wrapper{max-width:100%}.content-wrapper .result_list{width:120px;padding:0;overflow-x:scroll;overflow-y:hidden;cursor:pointer}.content-wrapper .result_list .listing .field-content{width:120px}.content-wrapper .result_list .listing td{padding:5px 10px}.content-wrapper .result_list .listing .field-moderator_reply{vertical-align:top}.content-wrapper .result_list .listing.full-width{margin-bottom:2em}.content-wrapper .result_list .listing.full-width td:first-child,.content-wrapper .result_list .listing.full-width th:first-child{padding:5px 0 5px 10px}.content-wrapper .changelist-filter{padding:0}.content-wrapper .changelist-filter #date_range_filter,.content-wrapper .changelist-filter h2,.content-wrapper .changelist-filter h3,.content-wrapper .changelist-filter ul{padding:0 15px}.content-wrapper .pagination{padding:0 15px}.content-wrapper .pagination.col9{width:100%}.content-wrapper .pagination.col9 p{padding:15px 0 0}.content-wrapper .pagination.col9 ul{padding:0 45px}.submit-row .button{margin:0 0 8px 0}@media screen and (min-width:50em){.content-wrapper .changelist-filter{padding:0;float:left;width:20%}.content-wrapper .changelist-filter #date_range_filter,.content-wrapper .changelist-filter h2,.content-wrapper .changelist-filter h3,.content-wrapper .changelist-filter ul{padding:0 0 0 5px}.content-wrapper .result_list{padding:0 0 0 10px;display:block;float:right;overflow-x:hidden;width:80%}.content-wrapper .pagination{padding:0}}